@@ -28,12 +28,12 @@ setup(
         'dsframework.base.tester',
         'dsframework.base.trainer',
     ],
-    package_data={'': ['config.json']},
+    package_data={'': ['config.json', 'cors_allowed_origins.json']},
     entry_points='''
         [console_scripts]
         dsf-cli=api_cli:cli
     ''',
-    version='0.1.28',
+    version='0.1.29',
     description='data science framework library',
     # url='http://pypi.python.org/pypi/PackageName/',
     author='oribrau@gmail.com',
@@ -53,7 +53,7 @@ setup(
 # for uninstall - python -m pip uninstall dsframework
 # for install - python -m pip install dist/dsframework-0.1.0-py3-none-any.whl
 
-# deploy to pipy
+# deploy to PyPI
 # delete dist and build folders
 # python setup-lib.py bdist_wheel
 # python setup-lib.py sdist
